**Example 1: 删除集群**



Input: 

```
tccli tdmq DeleteCluster --cli-unfold-argument  \
    --ClusterId pulsar-xxxxxxxx
```

Output: 
```
{
    "Response": {
        "ClusterId": "pulsar-5r59xd4vnx",
        "RequestId": "0f368d07-3648-4546-9c51-65dad19a3234"
    }
}
```

